aboutsummaryrefslogtreecommitdiff
path: root/contrib/llvm-project/llvm/include/llvm/IR/IntrinsicInst.h
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/llvm-project/llvm/include/llvm/IR/IntrinsicInst.h')
-rw-r--r--contrib/llvm-project/llvm/include/llvm/IR/IntrinsicInst.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/contrib/llvm-project/llvm/include/llvm/IR/IntrinsicInst.h b/contrib/llvm-project/llvm/include/llvm/IR/IntrinsicInst.h
index fc9111a4f512..4ff48c3669d5 100644
--- a/contrib/llvm-project/llvm/include/llvm/IR/IntrinsicInst.h
+++ b/contrib/llvm-project/llvm/include/llvm/IR/IntrinsicInst.h
@@ -84,7 +84,7 @@ public:
}
}
- // Checks if the intrinsic is an annotation.
+ /// Checks if the intrinsic is an annotation.
bool isAssumeLikeIntrinsic() const {
switch (getIntrinsicID()) {
default: break;
@@ -107,7 +107,11 @@ public:
return false;
}
- // Methods for support type inquiry through isa, cast, and dyn_cast:
+ /// Check if the intrinsic might lower into a regular function call in the
+ /// course of IR transformations
+ static bool mayLowerToFunctionCall(Intrinsic::ID IID);
+
+ /// Methods for support type inquiry through isa, cast, and dyn_cast:
static bool classof(const CallInst *I) {
if (const Function *CF = I->getCalledFunction())
return CF->isIntrinsic();
@@ -1356,9 +1360,6 @@ public:
}
};
-// Defined in Statepoint.h -- NOT a subclass of IntrinsicInst
-class GCStatepointInst;
-
/// Common base class for representing values projected from a statepoint.
/// Currently, the only projections available are gc.result and gc.relocate.
class GCProjectionInst : public IntrinsicInst {